@@ -20,6 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 import struct
+from typing import Optional
 
 from bitcoin.core import b2lx
 from bitcoin.core.serialize import ImmutableSerializable
@@ -148,7 +149,7 @@ class CSqueakHeader(ImmutableSerializable):
 
     def GetRecipientPubKey(self):
         """Return the recipient pub key."""
-        if self.is_private_message:
+        if not self.is_private_message:
             return None
         return SqueakPublicKey.from_bytes(self.recipientPubKey)
 
@@ -238,22 +239,39 @@ class CSqueak(CSqueakHeader):
         """Set the signature."""
         object.__setattr__(self, 'sig', sig)
 
-    def GetDecryptedContent(self, secret_key: bytes, recipientPrivKey: SqueakPrivateKey = None):
+    def GetDecryptedContent(
+            self,
+            secret_key: bytes,
+            authorPrivKey: Optional[SqueakPrivateKey] = None,
+            recipientPrivKey: Optional[SqueakPrivateKey] = None,
+    ):
         """Return the decrypted content."""
         CheckSqueakSecretKey(self, secret_key)
         data_key = sha256(secret_key)
         if self.is_private_message:
-            if recipientPrivKey is None:
-                raise Exception("Recipient private key required to get decrypted content of private squeak")
-            shared_secret = recipientPrivKey.get_shared_secret(self.GetPubKey())
+            if recipientPrivKey:
+                shared_secret = recipientPrivKey.get_shared_key(self.GetPubKey())
+            elif authorPrivKey:
+                shared_secret = authorPrivKey.get_shared_key(self.GetRecipientPubKey())
+            else:
+                raise Exception("Author or Recipient private key required to get decrypted content of private squeak")
             data_key = xor_bytes(data_key, shared_secret)
         iv = self.iv
         ciphertext = self.encContent
         return decrypt_content(data_key, iv, ciphertext)
 
-    def GetDecryptedContentStr(self, secret_key: bytes):
+    def GetDecryptedContentStr(
+            self,
+            secret_key: bytes,
+            authorPrivKey: Optional[SqueakPrivateKey] = None,
+            recipientPrivKey: Optional[SqueakPrivateKey] = None,
+    ):
         """Return the decrypted content."""
-        content = self.GetDecryptedContent(secret_key)
+        content = self.GetDecryptedContent(
+            secret_key,
+            authorPrivKey=authorPrivKey,
+            recipientPrivKey=recipientPrivKey,
+        )
         return DecodeContent(content)
 
 
@@ -400,8 +418,8 @@ def MakeSqueak(
         block_height: int,
         block_hash: bytes,
         timestamp: int,
-        reply_to: bytes = None,
-        recipient: SqueakPublicKey = None,
+        reply_to: Optional[bytes] = None,
+        recipient: Optional[SqueakPublicKey] = None,
 ):
     """Create a new squeak.
 
@@ -412,26 +430,26 @@ def MakeSqueak(
     block_height (int)
     block_hash (bytes)
     timestamp (int)
-    reply_to (bytes)
-    recipient (SqueakPublickey)
+    reply_to (Optional[bytes])
+    recipient (Optional[SqueakPublickey])
     """
     secret_key = generate_secret_key()
     data_key = sha256(secret_key)
     if recipient:
-        shared_secret = private_key.get_shared_secret(recipient)
+        shared_secret = private_key.get_shared_key(recipient)
         data_key = xor_bytes(data_key, shared_secret)
     initialization_vector = generate_initialization_vector()
     enc_content = EncryptContent(data_key, initialization_vector, content)
     hash_enc_content = HashEncryptedContent(enc_content)
     payment_point_encoded = payment_point_bytes_from_scalar_bytes(secret_key)
     nonce = generate_nonce()
-    verifying_key = private_key.get_public_key()
+    author_public_key = private_key.get_public_key()
     squeak = CSqueak(
         hashEncContent=hash_enc_content,
         hashReplySqk=reply_to or b'\x00'*HASH_LENGTH,
         hashBlock=block_hash,
         nBlockHeight=block_height,
-        pubKey=verifying_key.to_bytes(),
+        pubKey=author_public_key.to_bytes(),
         recipientPubKey=recipient.to_bytes() if recipient else b'\x00'*PUB_KEY_LENGTH,
         paymentPoint=payment_point_encoded,
         iv=initialization_vector,
@@ -464,8 +482,8 @@ def MakeSqueakFromStr(
         block_height: int,
         block_hash: bytes,
         timestamp: int,
-        reply_to: bytes = None,
-        recipient: SqueakPublicKey = None,
+        reply_to: Optional[bytes] = None,
+        recipient: Optional[SqueakPublicKey] = None,
 ):
     """Create a new squeak from a string of content.
 
@@ -476,8 +494,8 @@ def MakeSqueakFromStr(
     block_height (int)
     block_hash (bytes)
     timestamp (int)
-    reply_to (bytes)
-    recipient (SqueakPublickey)
+    reply_to (Optional[bytes])
+    recipient (Optional[SqueakPublickey])
     """
     reply_to = reply_to or b'\x00'*HASH_LENGTH
     content = EncodeContent(content_str)
